<?php
namespace Teknisa\PLA\Modules\Prato\Controllers;

use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class Pla00470EmbalagemTransportada extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName = "contembalag";
    protected $entityManager;

    public function __construct($crudService, $parameterBag, $entityManager) {
    	$this->crudService = $crudService;
    	$this->parameterBag = $parameterBag;
    	$this->entityManager = $entityManager;
    }

    public function salvaEmbalagemTransportada(DTO\Request $request, DTO\Response $response) {
    	try {
            $row = $request->getRow();
            if ($row['__is_new']) {
                $this->verificaEmbalagemJaCadastrada($row);
                $row['NRCONTEMBALAG'] = $this->retornaProximoCodigo();
                $response->addDataset(new DataSet('NRCONTEMBALAG', array($row['NRCONTEMBALAG'])));
            }
            parent::save($request, $response);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    private function retornaProximoCodigo() {
		$sql = "SELECT NVL(MAX(NRCONTEMBALAG), 0) + 1 AS NRCONTEMBALAG FROM CONTEMBALAG WHERE NRORG = :NRORG";
		$params = array("NRORG" => $this->crudService->getEnvironment()->getNrOrg());
		$query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        return $result[0]['NRCONTEMBALAG'];
	}

	private function verificaEmbalagemJaCadastrada($row) {
		$sql = "SELECT NRCONTEMBALAG FROM CONTEMBALAG WHERE NRORG = :NRORG AND CDEMBALAGEM = :CDEMBALAGEM AND CDCONTAINER = :CDCONTAINER";
		$params = array(
			"NRORG" => $this->crudService->getEnvironment()->getNrOrg(),
			"CDCONTAINER" => $row["CDCONTAINER"],
			"CDEMBALAGEM" => $row["CDEMBALAGEM"],
		);
		$query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();

        if (sizeof($result) > 0) {
        	throw new \Exception("Impossível adicionar. Registro já existe.");
        }
	}

}